diff mbox series

[1/3] ASoC: rsnd: don't use discriminatory terms for function names

Message ID 87pn903svl.wl-kuninori.morimoto.gx@renesas.com (mailing list archive)
State New, archived
Headers show
Series ASoC: sh: remove discriminatory terms | expand

Commit Message

Kuninori Morimoto July 13, 2020, 5:08 a.m. UTC
From: Kuninori Morimoto <kuninori.morimoto.gx@renesas.com>

rsnd is using discriminatory terms for function names.
This patch change it to "follower"

Signed-off-by: Kuninori Morimoto <kuninori.morimoto.gx@renesas.com>
---
 sound/soc/sh/rcar/rsnd.h |  2 +-
 sound/soc/sh/rcar/ssi.c  | 28 ++++++++++++++--------------
 sound/soc/sh/rcar/ssiu.c |  6 +++---
 3 files changed, 18 insertions(+), 18 deletions(-)

Comments

Hector Martin July 13, 2020, 4:44 p.m. UTC | #1
On 13/07/2020 14.08, Kuninori Morimoto wrote:
> -u32 rsnd_ssi_multi_slaves_runtime(struct rsnd_dai_stream *io);
> +u32 rsnd_ssi_multi_followers_runtime(struct rsnd_dai_stream *io);

I don't have full context here, but AIUI this is about bundling 
different links together? If so, primary/secondary or main/secondary 
might work better than leader/follower, in my opinion. The latter 
implies more of a "one device follows another one" scenario, like for 
clocks.

Just my 2c. Ditching the horribly ambiguous master/slave terminology is 
a good chance to pick the replacement that best describes the situation :-)
Mark Brown July 13, 2020, 5:16 p.m. UTC | #2
On Tue, Jul 14, 2020 at 01:44:40AM +0900, Hector Martin 'marcan' wrote:
> On 13/07/2020 14.08, Kuninori Morimoto wrote:

> > -u32 rsnd_ssi_multi_slaves_runtime(struct rsnd_dai_stream *io);
> > +u32 rsnd_ssi_multi_followers_runtime(struct rsnd_dai_stream *io);

> I don't have full context here, but AIUI this is about bundling different
> links together? If so, primary/secondary or main/secondary might work better
> than leader/follower, in my opinion. The latter implies more of a "one
> device follows another one" scenario, like for clocks.

That does make sense to me.
Kuninori Morimoto July 13, 2020, 11:13 p.m. UTC | #3
Hi Hector, Mark

> > > -u32 rsnd_ssi_multi_slaves_runtime(struct rsnd_dai_stream *io);
> > > +u32 rsnd_ssi_multi_followers_runtime(struct rsnd_dai_stream *io);
> 
> > I don't have full context here, but AIUI this is about bundling different
> > links together? If so, primary/secondary or main/secondary might work better
> > than leader/follower, in my opinion. The latter implies more of a "one
> > device follows another one" scenario, like for clocks.
> 
> That does make sense to me.

Thank you for your advice.
I will use "secondary" in v2

Thank you for your help !!

Best regards
---
Kuninori Morimoto
diff mbox series

Patch

diff --git a/sound/soc/sh/rcar/rsnd.h b/sound/soc/sh/rcar/rsnd.h
index d47608ff5fac..2b5a096dc330 100644
--- a/sound/soc/sh/rcar/rsnd.h
+++ b/sound/soc/sh/rcar/rsnd.h
@@ -775,7 +775,7 @@  int rsnd_ssi_probe(struct rsnd_priv *priv);
 void rsnd_ssi_remove(struct rsnd_priv *priv);
 struct rsnd_mod *rsnd_ssi_mod_get(struct rsnd_priv *priv, int id);
 int rsnd_ssi_use_busif(struct rsnd_dai_stream *io);
-u32 rsnd_ssi_multi_slaves_runtime(struct rsnd_dai_stream *io);
+u32 rsnd_ssi_multi_followers_runtime(struct rsnd_dai_stream *io);
 
 #define rsnd_ssi_is_pin_sharing(io)	\
 	__rsnd_ssi_is_pin_sharing(rsnd_io_to_mod_ssi(io))
diff --git a/sound/soc/sh/rcar/ssiu.c b/sound/soc/sh/rcar/ssiu.c
index 9c7c3e7539c9..7565d0fc16f6 100644
--- a/sound/soc/sh/rcar/ssiu.c
+++ b/sound/soc/sh/rcar/ssiu.c
@@ -60,7 +60,7 @@  static int rsnd_ssiu_init(struct rsnd_mod *mod,
 			  struct rsnd_priv *priv)
 {
 	struct rsnd_dai *rdai = rsnd_io_to_rdai(io);
-	u32 ssis = rsnd_ssi_multi_slaves_runtime(io);
+	u32 ssis = rsnd_ssi_multi_followers_runtime(io);
 	int use_busif = rsnd_ssi_use_busif(io);
 	int id = rsnd_mod_id(mod);
 	int is_clk_master = rsnd_rdai_is_clk_master(rdai);
@@ -246,7 +246,7 @@  static int rsnd_ssiu_start_gen2(struct rsnd_mod *mod,
 
 	rsnd_mod_bset(mod, SSI_CTRL, 1 << (busif * 4), 1 << (busif * 4));
 
-	if (rsnd_ssi_multi_slaves_runtime(io))
+	if (rsnd_ssi_multi_followers_runtime(io))
 		rsnd_mod_write(mod, SSI_CONTROL, 0x1);
 
 	return 0;
@@ -267,7 +267,7 @@  static int rsnd_ssiu_stop_gen2(struct rsnd_mod *mod,
 	if (--ssiu->usrcnt)
 		return 0;
 
-	if (rsnd_ssi_multi_slaves_runtime(io))
+	if (rsnd_ssi_multi_followers_runtime(io))
 		rsnd_mod_write(mod, SSI_CONTROL, 0);
 
 	return 0;
diff --git a/sound/soc/sh/rcar/ssi.c b/sound/soc/sh/rcar/ssi.c
index 47d5ddb526f2..6333f40fb566 100644
--- a/sound/soc/sh/rcar/ssi.c
+++ b/sound/soc/sh/rcar/ssi.c
@@ -111,8 +111,8 @@  struct rsnd_ssi {
 #define rsnd_ssi_nr(priv) ((priv)->ssi_nr)
 #define rsnd_mod_to_ssi(_mod) container_of((_mod), struct rsnd_ssi, mod)
 #define rsnd_ssi_is_parent(ssi, io) ((ssi) == rsnd_io_to_mod_ssip(io))
-#define rsnd_ssi_is_multi_slave(mod, io) \
-	(rsnd_ssi_multi_slaves(io) & (1 << rsnd_mod_id(mod)))
+#define rsnd_ssi_is_multi_follower(mod, io)\
+	(rsnd_ssi_multi_followers(io) & (1 << rsnd_mod_id(mod)))
 #define rsnd_ssi_is_run_mods(mod, io) \
 	(rsnd_ssi_run_mods(io) & (1 << rsnd_mod_id(mod)))
 #define rsnd_ssi_can_output_clk(mod) (!__rsnd_ssi_is_pin_sharing(mod))
@@ -165,7 +165,7 @@  static void rsnd_ssi_status_check(struct rsnd_mod *mod,
 	dev_warn(dev, "%s status check failed\n", rsnd_mod_name(mod));
 }
 
-static u32 rsnd_ssi_multi_slaves(struct rsnd_dai_stream *io)
+static u32 rsnd_ssi_multi_followers(struct rsnd_dai_stream *io)
 {
 	struct rsnd_mod *mod;
 	enum rsnd_mod_type types[] = {
@@ -193,7 +193,7 @@  static u32 rsnd_ssi_run_mods(struct rsnd_dai_stream *io)
 	struct rsnd_mod *ssi_parent_mod = rsnd_io_to_mod_ssip(io);
 	u32 mods;
 
-	mods = rsnd_ssi_multi_slaves_runtime(io) |
+	mods = rsnd_ssi_multi_followers_runtime(io) |
 		1 << rsnd_mod_id(ssi_mod);
 
 	if (ssi_parent_mod)
@@ -202,10 +202,10 @@  static u32 rsnd_ssi_run_mods(struct rsnd_dai_stream *io)
 	return mods;
 }
 
-u32 rsnd_ssi_multi_slaves_runtime(struct rsnd_dai_stream *io)
+u32 rsnd_ssi_multi_followers_runtime(struct rsnd_dai_stream *io)
 {
 	if (rsnd_runtime_is_multi_ssi(io))
-		return rsnd_ssi_multi_slaves(io);
+		return rsnd_ssi_multi_followers(io);
 
 	return 0;
 }
@@ -283,7 +283,7 @@  static int rsnd_ssi_master_clk_start(struct rsnd_mod *mod,
 	if (!rsnd_ssi_can_output_clk(mod))
 		return 0;
 
-	if (rsnd_ssi_is_multi_slave(mod, io))
+	if (rsnd_ssi_is_multi_follower(mod, io))
 		return 0;
 
 	if (rsnd_runtime_is_tdm_split(io))
@@ -626,7 +626,7 @@  static int rsnd_ssi_start(struct rsnd_mod *mod,
 	 * EN will be set via SSIU :: SSI_CONTROL
 	 * if Multi channel mode
 	 */
-	if (rsnd_ssi_multi_slaves_runtime(io))
+	if (rsnd_ssi_multi_followers_runtime(io))
 		return 0;
 
 	/*
@@ -675,7 +675,7 @@  static int rsnd_ssi_stop(struct rsnd_mod *mod,
 	/* In multi-SSI mode, stop is performed by setting ssi0129 in
 	 * SSI_CONTROL to 0 (in rsnd_ssio_stop_gen2). Do nothing here.
 	 */
-	if (rsnd_ssi_multi_slaves_runtime(io))
+	if (rsnd_ssi_multi_followers_runtime(io))
 		return 0;
 
 	/*
@@ -888,7 +888,7 @@  static void rsnd_ssi_parent_attach(struct rsnd_mod *mod,
 	if (!rsnd_rdai_is_clk_master(rdai))
 		return;
 
-	if (rsnd_ssi_is_multi_slave(mod, io))
+	if (rsnd_ssi_is_multi_follower(mod, io))
 		return;
 
 	switch (rsnd_mod_id(mod)) {
@@ -930,9 +930,9 @@  static int rsnd_ssi_common_probe(struct rsnd_mod *mod,
 
 	/*
 	 * SSIP/SSIU/IRQ are not needed on
 	 * SSI Multi slaves
 	 */
-	if (rsnd_ssi_is_multi_slave(mod, io))
+	if (rsnd_ssi_is_multi_follower(mod, io))
 		return 0;
 
 	/*
@@ -1091,9 +1091,9 @@  static int rsnd_ssi_dma_probe(struct rsnd_mod *mod,
 
 	/*
 	 * SSIP/SSIU/IRQ/DMA are not needed on
 	 * SSI Multi slaves
 	 */
-	if (rsnd_ssi_is_multi_slave(mod, io))
+	if (rsnd_ssi_is_multi_follower(mod, io))
 		return 0;
 
 	ret = rsnd_ssi_common_probe(mod, io, priv);
@@ -930,9 +930,9 @@  static int rsnd_ssi_common_probe(struct rsnd_mod *mod,
 	/*
 	 * SSIP/SSIU/IRQ are not needed on
-	 * SSI Multi slaves
+	 * SSI Multi followers
 	 */
@@ -1091,9 +1091,9 @@  static int rsnd_ssi_dma_probe(struct rsnd_mod *mod,
 	/*
 	 * SSIP/SSIU/IRQ/DMA are not needed on
-	 * SSI Multi slaves
+	 * SSI Multi followers
 	 */